Struct ExtScsiPassThruProtocol
Source #[repr(C)]
pub struct ExtScsiPassThruProtocol {
pub passthru_mode: *const ExtScsiPassThruMode,
pub pass_thru: unsafe extern "efiapi" fn(this: *mut Self, target: *const u8, lun: u64, packet: *mut ScsiIoScsiRequestPacket, event: Event) -> Status,
pub get_next_target_lun: unsafe extern "efiapi" fn(this: *const Self, target: *mut *mut u8, lun: *mut u64) -> Status,
pub build_device_path: unsafe extern "efiapi" fn(this: *const Self, target: *const u8, lun: u64, device_path: *mut *const DevicePathProtocol) -> Status,
pub get_target_lun: unsafe extern "efiapi" fn(this: *const Self, device_path: *const DevicePathProtocol, target: *mut *const u8, lun: *mut u64) -> Status,
pub reset_channel: unsafe extern "efiapi" fn(this: *mut Self) -> Status,
pub reset_target_lun: unsafe extern "efiapi" fn(this: *mut Self, target: *const u8, lun: u64) -> Status,
pub get_next_target: unsafe extern "efiapi" fn(this: *const Self, target: *mut *mut u8) -> Status,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.