Struct ScsiIoProtocol
Source #[repr(C)]
pub struct ScsiIoProtocol {
pub get_device_type: unsafe extern "efiapi" fn(this: *const Self, device_type: *mut ScsiIoType) -> Status,
pub get_device_location: unsafe extern "efiapi" fn(this: *const Self, target: *mut *mut u8, lun: *mut u64) -> Status,
pub reset_bus: unsafe extern "efiapi" fn(this: *mut Self) -> Status,
pub reset_device: unsafe extern "efiapi" fn(this: *mut Self) -> Status,
pub execute_scsi_command: unsafe extern "efiapi" fn(this: *const Self, packet: *mut ScsiIoScsiRequestPacket, event: Event) -> Status,
pub io_align: u32,
}
execute_scsi_command: unsafe extern "efiapi" fn(this: *const Self, packet: *mut ScsiIoScsiRequestPacket, event: Event) -> Status
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.